@@ -474,16 +474,19 @@ def generate_code(rules, clean_before=False):
         f.write('namespace apg {\n\n')
 
         # Function to convert rulestring to rule integer:
-        not_used = True
-        f.write('    std::string get_zoi(std::string rule) {\n')
-        for (fam, r) in zip(families, rules):
-            if (fam >= 6):
-                f.write('        if (rule == "%s") { return "%s"; }\n' % (r, genera.rule_property(r, 'zoi')))
-                not_used = False
-        if not_used:
-            f.write('        (void) rule;\n')
-        f.write('        return "99";\n')
-        f.write('    }\n\n')
+
+        for prop in ['zoi', 'syms']:
+
+            not_used = True
+            f.write('    std::string get_%s(std::string rule) {\n' % prop)
+            for (fam, r) in zip(families, rules):
+                if (fam >= 6):
+                    f.write('        if (rule == "%s") { return "%s"; }\n' % (r, genera.rule_property(r, prop)))
+                    not_used = False
+            if not_used:
+                f.write('        (void) rule;\n')
+            f.write('        return "99";\n')
+            f.write('    }\n\n')
 
         # Function to convert rulestring to rule integer:
         f.write('    int rule2int(std::string rule) {\n')
