@@ -376,10 +376,8 @@ namespace apg {
             outstream << "[M2] (lifelib " << LIFELIB_VERSION << ")" << std::endl;
         }
 
-        void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) {
-            if (rule != "") { outstream << "#R " << gollyrule(rule) << std::endl; }
-            std::map<std::pair<I, uint32_t>, uint64_t> hnode2int;
-            uint64_t linenum = 0;
+        void write_macrocell_headerless(std::ostream &outstream, std::vector<hypernode<I> > &hnodes, 
+                                        std::string rule, int multistate, int timeline, uint64_t gencount) {
 
             bool write_multistate;
 
@@ -389,14 +387,47 @@ namespace apg {
                 default : write_multistate = (N > 1); break; // 2 : infer
             }
 
+            if (write_multistate) { outstream << "#CLL state-numbering lifelib" << std::endl; }
+            if (rule != "")       { outstream << "#R " << gollyrule(rule) << std::endl; }
+            if (timeline < 0)     {
+                outstream << "#G " << gencount << std::endl;
+            } else {
+                outstream << "#FRAMES " << hnodes.size() << " " << gencount << " 2^" << timeline << std::endl;
+            }
+
+            std::vector<uint64_t> framevec;
+            std::map<std::pair<I, uint32_t>, uint64_t> hnode2int;
+            uint64_t linenum = 0;
+
             if (write_multistate) {
-                outstream << "#CLL state-numbering lifelib" << std::endl;
                 std::map<std::string, uint64_t> subleaf2int;
-                write_macrocell_recurse(outstream, breach(hnode), &subleaf2int, &hnode2int, linenum);
+                for (uint64_t i = 0; i < hnodes.size(); i++) {
+                    auto hnode = breach(hnodes[i]);
+                    framevec.push_back(write_macrocell_recurse(outstream, hnode, &subleaf2int, &hnode2int, linenum));
+                }
             } else {
                 std::map<uint64_t, uint64_t> subleaf2int;
-                write_macrocell_recurse(outstream, breach(hnode), &subleaf2int, &hnode2int, linenum);
+                for (uint64_t i = 0; i < hnodes.size(); i++) {
+                    auto hnode = breach(hnodes[i]);
+                    framevec.push_back(write_macrocell_recurse(outstream, hnode, &subleaf2int, &hnode2int, linenum));
+                }
             }
+
+            if (timeline >= 0) {
+                for (uint64_t i = 0; i < framevec.size(); i++) {
+                    outstream << "#FRAME " << i << " " << framevec[i] << std::endl;
+                }
+            }
+        }
+
+        void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate, uint64_t gencount) {
+            std::vector<hypernode<I> > hnodes;
+            hnodes.push_back(hnode);
+            write_macrocell_headerless(outstream, hnodes, rule, multistate, -1, gencount);
+        }
+
+        void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) {
+            write_macrocell_headerless(outstream, hnode, rule, multistate, 0);
         }
 
         void write_macrocell(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) {
