@@ -72,6 +72,8 @@ namespace apg {
         virtual void write_macrocell(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) = 0;
         virtual void write_macrocell_header(std::ostream &outstream) = 0;
         virtual void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) = 0;
+        virtual void write_macrocell_headerless(std::ostream &outstream, std::vector<hypernode<I> > &hnodes, 
+                                        std::string rule, int multistate, int timeline, uint64_t gencount) = 0;
         virtual void getcells_recurse(hypernode<I> hnode, uint64_t x, uint64_t y, std::map<std::pair<uint64_t, uint64_t>, uint64_t> &cells) = 0;
         virtual void write_rle(std::ostream &outstream, hypernode<I> hnode, std::string rule) = 0;
         virtual hypernode<I> _string32(std::string s) = 0;
