@@ -551,14 +551,14 @@ namespace apg {
             return syms;
         }
 
-        std::string phase_wechsler(std::string syms) {
+        std::string phase_wechsler(int64_t maxarea, std::string syms) {
             /*
             * Returns the extended Wechsler format for the current phase:
             */
             int64_t bbox[4] = {0};
             if (getrect(bbox)) {
 
-                if ((bbox[2] + 2) * (bbox[3] + 2) > 10000) { return "#"; }
+                if ((bbox[2] + 2) * (bbox[3] + 2) > maxarea) { return "#"; }
 
                 uint64_t n_layers = lab->countlayers();
                 std::vector<bitworld> bwv;
@@ -571,25 +571,22 @@ namespace apg {
                 }
 
                 if (syms == "HEXAGONAL") {
-                    std::string s = wechslerhex(bwv);
-                    return ((s.length() > 1280) ? "#" : s);
+                    return wechslerhex(bwv);
                 } else if (syms == "SQUARE") {
-                    std::string s = wechslerise(bwv, bbox);
-                    return ((s.length() > 1280) ? "#" : s);
+                    return wechslerise(bwv, bbox);
                 } else {
-                    std::string s = wechslernone(bwv, bbox);
-                    return ((s.length() > 1280) ? "#" : s);
+                    return wechslernone(bwv, bbox);
                 }
             } else {
                 return "0";
             }
         }
 
-        std::string phase_wechsler() {
-            return phase_wechsler(rule_symmetries());
+        std::string phase_wechsler(int64_t maxarea) {
+            return phase_wechsler(maxarea, rule_symmetries());
         }
 
-        std::string apgcode() {
+        std::string apgcode(int maxarea, int maxlength) {
             /*
             * Returns the apgcode of a still-life, oscillator or spaceship:
             */
@@ -604,8 +601,8 @@ namespace apg {
 
             for (uint64_t t = 0; t < p; t++) {
                 if (t != 0) { x = x.advance((rulestring[1] == '0') ? 2 : 1); }
-                // rep = comprep(rep, x.flatlayer(0).wechsler());
-                rep = comprep(rep, x.phase_wechsler(syms));
+                std::string phase_rep = x.phase_wechsler(maxarea, syms);
+                if (phase_rep.length() <= maxlength) { rep = comprep(rep, phase_rep); }
             }
 
             std::ostringstream ss;
@@ -626,6 +623,8 @@ namespace apg {
             return ss.str();
         }
 
+        std::string apgcode() { return apgcode(10000, 1280); }
+
         basepattern<I> advance2(int64_t numgens, uint64_t exponent) {
             /*
             * Advance a basepattern<I> by a number of generations. If the basepattern<I>
